# -- coding: utf-8 --
# @Time : 2024/6/6 10:41
# @Author : PinBar
# @File : example.py
from typing import Annotated

from fastapi import Body, Form, Query

from core.base_view import BaseView
from core.decorator import api_description



